#
# spec file for package flawfinder
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flawfinder
Version:        2.0.11
Release:        bp153.1.14
Summary:        C/C++ source code security flaw examination tool
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            http://www.dwheeler.com/flawfinder/
Source:         http://www.dwheeler.com/flawfinder/%{name}-%{version}.tar.gz
Requires:       python3
BuildArch:      noarch

%description
Flawfinder scans through C/C++ source code, identifying lines
("hits") with potential security flaws. By default it reports hits
sorted by severity, with the riskiest lines first.

%prep
%setup -q
sed -i "s|!/usr/bin/env python|!/usr/bin/python3|" flawfinder
chmod -x *.ps

%build
make %{?_smp_mflags}

%install
install -m755 -D flawfinder %{buildroot}%{_bindir}/flawfinder
install -m644 -D flawfinder.1 %{buildroot}%{_mandir}/man1/flawfinder.1

%files
%license COPYING
%doc README.md ChangeLog flawfinder.ps
%{_bindir}/flawfinder
%{_mandir}/man1/flawfinder.1%{?ext_man}

%changelog
* Tue Feb 18 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.0.11:
  * Provide a much more detailed error report, including recommended
    solutions, when character encoding problems hit.
    As Python3 has slowly gained in popularity, its failure to provide
    useful built-ins to handle real-world character encoding problems
    hurts more people. (E.g., many files don't comply with *any*
    character set encoding standard, and Python3 can't read them
    without enabling options that are wrong for others.)
    We can at least provide much more detailed feedback to help
    explain the various options available.
* Thu Sep  5 2019 mvetter@suse.com
- Use python3
* Thu Sep  5 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Drop metadata redundancies from
  description.
* Wed Sep  4 2019 mvetter@suse.com
- Update to 2.0.10:
  * Use binary mode when reading a diffhitlist.
  * Fix a serious defect in --diffhitlist option and added a
    unit test
  * Don't warn if memcpy call includes sizeof(first arg).
  * Bugfix (banned function _ftcsat should be _ftcscat).
  * Documentation tweaks. Make it clear that GitHub issues and
  pull requests are supported, and use ~~~~ in markdown
  to ease copy-and-paste from documentation.
* Fri Jan 18 2019 mvetter@suse.com
- Update to 2.0.7:
  * Incorporate many small improvements from nickthetait
  * Fix a number of bugs reported by philipp
  * Update URLs for www.dwheeler.com -> dwheeler.com
- Highlights from older versions:
  * add detection of crypt_r function
  * add detection of errant equal, mismatch, and is_permutation
  * update CWE, risk, and discussion for C++14 STL functions
  * Always report hit counts correctly, even if ignored using -m
  * Switch from distutils to setuptools
  * Flawfinder can now run on either Python 2.7 or 3
  * Change version numbers to use Semantic Versioning (x.y.z)
  * Add support for generating CSV (comma-separated value) format,
  to make this tool easier to integrate into larger toolsuites.
* Thu Feb 19 2015 tuukka.pasanen@ilmi.fi
- New version 1.31
